@@ -55,7 +55,8 @@ class FFMPEG_VideoWriter:
                                  stderr=sp.PIPE)
         
     def write_frame(self,img_array):
-        self.proc.stdin.write(img_array.tostring())
+        #self.proc.stdin.write(img_array.tostring())
+        img_array.tofile(self.proc.stdin)
         
     def close(self):
         self.proc.stdin.close()
