@@ -94,8 +94,7 @@ def preview(clip, fps=15, audio=True, audio_fps=22050,
         for event in pg.event.get():
                 if event.type == pg.KEYDOWN:
                     if (event.key == pg.K_ESCAPE):
-                        pg.mixer.stop()
-                        pg.mixer.quit()
+                        videoFlag.clear()
                         print "Keyboard interrupt"
                         return
                         
